﻿* Encoding: UTF-8. 
***************************************************************
* Syntaxfile, das ESeG des Befragten, des Ehepartners,
* des Lebenspartners, des Vaters und der Mutter fuer 
* die ALLBUS-Kumulation 1980-2016 (ZA4586) generiert.
*
* Diese Syntax ist angelehnt an die SPSS-Routine von 
* Jeanette Bohr (2018) und berücksichtigt die 
* ESeG-Revisionen von 2014 und 2016.
*
* Jeanette Bohr 2018: EU-AES Tools: Implementation of 
* the European Socioeconomic Groups Classification (ESeG) 
* using Adult Education Survey Microdata, GESIS Papers, 
* Köln: GESIS - Leibniz-Institut für Sozialwissenschaften.
*
* Weitere Informationen siehe:
* Sarah Thiesen und Sonja Schulz 2019: Bildung der European 
* Socioeconomic Groups (ESeG) im ALLBUS, GESIS-Servicedokument, 
* Köln: GESIS - Leibniz-Institut für Sozialwissenschaften.
*
* (c) GESIS 2019
* GESIS - Leibniz-Institut für Sozialwisschenschaften
* Datenarchiv für Sozialwissenschaften (DAS)
* https://www.gesis.org/allbus
***************************************************************.

*Bitte Arbeitsordner einsetzen:.
cd "<Pfad>".

*Bitte Dateinamen anpassen:.
GET FILE='ZA4586_v1-0-0.sav'.

**************************************
*Vorbereitung.

* Definition der Missing Values aufheben.
missing values isco08 dw01 dw03 work isco08a dw01a mstat scisco08 scdw01 scdw03 scwork pisco08 pdw01 pdw03 pwork fdw01 fisco08 mdw01 misco08 (). 

*ISCO-08 auf die ersten beiden Stellen kuerzen.
do repeat #ISCO = isco08 isco08a scisco08 pisco08 fisco08 misco08
        / #ISCOneu = isco08neu isco08aneu scisco08neu pisco08neu fisco08neu misco08neu.
compute #ISCOneu = TRUNC(#ISCO / 100).
if (#ISCO < 0) #ISCOneu = #ISCO.
end repeat.

*Variable selbststaendig/abhaengig beschaeftigt.
do repeat #STAT = STA STAa scSTA pSTA fSTA mSTA
        / #DW = dw01 dw01a scdw01 pdw01 fdw01 mdw01.
compute #STAT = #DW.
if any(#DW, 1, 2, 3, 8) #STAT = 1.
if any(#DW, 4, 5, 6, 7) #STAT = 2.
if (#DW = 9) #STAT = -32.
end repeat.

val labs STA STAa scSTA pSTA fSTA mSTA
    1 'self-employed'
    2 'employed'
    -10 'TRIFFT NICHT ZU'
    -9 'KEINE ANGABE'
    -32 'NICHT GENERIERBAR'.

**************************************.
**************************************.

*******ESeG.********.

**** Gruppen 1 bis 7.
do repeat #ESEG = eseg sceseg peseg feseg meseg
        / #ISCO = isco08neu scisco08neu pisco08neu fisco08neu misco08neu
        / #STAT = STA scSTA pSTA fSTA mSTA.

compute #ESEG = 0.

*** 1 Managers.
if (#ISCO >= 10 and #ISCO <= 14) or (#ISCO = 01 and #STAT = 2) #ESEG = 10. 
*1.1 Higher managerial self-employed (ISCO 11, 12, 13 and STATUS=se).
if (any(#ISCO, 11, 12, 13) and #STAT = 1) #ESEG = 11 .
*1.2 Lower managerial self-employed (ISCO 14 and STATUS=se).
if (#ISCO = 14 and #STAT = 1) #ESEG = 12.
*1.3 Higher managerial employees (ISCO 11, 12, 13 and 01 and STATUS=e).
if (any(#ISCO, 01, 11, 12, 13) and #STAT = 2) #ESEG = 13.
*1.4 Lower managerial employees (ISCO 14 and STATUS=e).
if (#ISCO = 14 and #STAT = 2) #ESEG = 14.

*** 2 Professionals: ISCO = 21, 22, 23, 24, 25, 26.
if (#ISCO >= 20 and #ISCO <= 26) #ESEG = 20. 
*2.1 Science, engineering and information and communications technology (ICT) professionnals (ISCO 21,25).
if any(#ISCO, 21, 25) #ESEG = 21.
*2.2 Health professionals (ISCO 22).
if (#ISCO = 22) #ESEG = 22.
*2.3 Business and administration professionals (ISCO 24).
if (#ISCO = 24) #ESEG = 23.
*2.4 Legal, social and cultural professionals (ISCO 26).
if (#ISCO = 26) #ESEG = 24.
*2.5 Teaching professionals (ISCO 23).
if (#ISCO = 23) #ESEG = 25.

*** 3 Technicians and associated professional employees: ISCO = 02, 31, 32, 33, 34, 35.
if ((#ISCO >= 30 and #ISCO <= 35) or (#ISCO = 02)) and (#STAT = 2) #ESEG = 30. 
*3.1 Science, engineering and ICT technicians and associated professionals (ISCO 31, 35).
if (any(#ISCO, 31, 35) and #STAT = 2) #ESEG = 31.
*3.2 Health associate professionals (ISCO 32).
if (#ISCO = 32 and #STAT = 2) #ESEG = 32.
*3.3 Business and administration associate professionals (ISCO 33).
if (#ISCO = 33 and #STAT = 2) #ESEG = 33.
*3.4 Legal, social and cultural associate professionals (ISCO 34).
if (#ISCO = 34 and #STAT = 2) #ESEG = 34.
*3.5 Non-commissioned armed forces officers (ISCO 02 ).
if (#ISCO = 02 and #STAT = 2) #ESEG = 35.

*** 4 Small entrepreneurs: ISCO = 3, 4, 5, 6, 7, 8, 9.
if ((#ISCO >= 30 and #ISCO <= 96) and #STAT = 1) #ESEG = 40. 
*4.1 Skilled agricultural self employed workers (ISCO 6).
if (any(#ISCO, 60, 61, 62, 63, 92) and #STAT = 1) #ESEG = 41.
*4.2 Technicians, clerical support, services and sales self employed workers (ISCO 3, 4, 5).
if (#ISCO >= 31 and #ISCO <= 54 and #STAT = 1) #ESEG = 42.
*4.3 Craft and related trades self employed workers (ISCO 7, 8, 9, except 92).
if (#ISCO >= 71 and #ISCO <= 96 and #ISCO ne 92 and #STAT = 1) #ESEG = 43.

*** 5 Clerks and skilled service employees: ISCO = 41, 42, 43, 44, 53, 54, 03, 04.
if (any(#ISCO, 40, 41, 42, 43, 44, 53, 54, 03, 04)) and (#STAT = 2) #ESEG = 50.
*5.1 General and numerical clerks and other clerical support employees (ISCO 41, 43, 44).
if (any(#ISCO, 41,  43, 44) and #STAT = 2) #ESEG = 51.
*5.2 Customer services clerks (ISCO 42).
if (#ISCO = 42 and #STAT = 2) #ESEG = 52.
*5.3 Personal care employees (ISCO 53).
if (#ISCO = 53 and #STAT = 2) #ESEG = 53.
*5.4 Armed forced occupations and protective service employees (ISCO 03, 04 and ISCO 54).
if (any(#ISCO, 03, 04, 54) and #STAT = 2) #ESEG = 54.
 
*** 6 Skilled industrial employees: ISCO = 71, 72, 73, 74, 75, 81, 82, 83.
if ((#ISCO >= 70 and #ISCO <= 83) and #STAT = 2) #ESEG = 60. 
*6.1 Building and related trade employees (ISCO 71).
if (#ISCO = 71 and #STAT = 2) #ESEG = 61.
*6.2 Food processing, wood working, garment employees (ISCO 75).
if (#ISCO = 75 and #STAT = 2) #ESEG = 62.
*6.3 Metal, machinery, handicraft, printing, electrical and electronic trades employees (ISCO 72, 73, 74).
if (any(#ISCO, 72, 73, 74) and #STAT = 2) #ESEG = 63.
*6.4 Stationary plant and machine operators and assemblers (ISCO 81, 82).
if (any(#ISCO, 81, 82) and #STAT = 2) #ESEG = 64.
*6.5 Drivers (ISCO 83).
if (#ISCO = 83 and #STAT = 2) #ESEG = 65.

*** 7 Lower status employees: ISCO = 51, 52, 90, 91, 92, 93, 94, 95, 96, 6.
if (any(#ISCO, 51, 52, 60, 61, 62, 63, 90, 91, 92, 93, 94, 95, 96)) and (#STAT = 2) #ESEG = 70. 
*7.1 Personal services and sales employees (ISCO 51, 52).
if (any(#ISCO, 51, 52) and #STAT = 2) #ESEG = 71.
*7.2 Blue collar employees and food preparation assistants in elementary occupations (ISCO 93, 94, 96).
if (any(#ISCO, 93, 94, 96) and #STAT = 2) #ESEG = 72.
*7.3 Cleaners and helpers and services employees in elementary occupations (ISCO 91, 95).
if (any(#ISCO, 91, 95) and #STAT = 2) #ESEG = 73.
*7.4 Agricultural employees (ISCO 6, 92).
if (any(#ISCO, 60, 61, 62, 63, 92) and #STAT = 2) #ESEG = 74.

end repeat.

* Befragter - Klassifizierung der Arbeitslosen.
if (isco08aneu >= 10 and isco08aneu <= 14) and (dw03 = 3) eseg = 10.
if (any(isco08aneu, 11, 12, 13) and STAa = 1 and dw03 = 3) eseg = 11.
if (isco08aneu = 14 and STAa = 1 and dw03 = 3) eseg = 12.
if (any(isco08aneu, 01, 11, 12, 13) and STAa = 2 and dw03 = 3) eseg = 13.
if (isco08aneu = 14 and STAa = 2 and dw03 = 3) eseg = 14.
if (isco08aneu = 20 and dw03 = 3) eseg = 20.
if any(isco08aneu, 21, 25) and dw03 = 3 eseg = 21.
if (isco08aneu = 22 and dw03 = 3) eseg = 22.
if (isco08aneu = 24 and dw03 = 3) eseg = 23.
if (isco08aneu = 26 and dw03 = 3) eseg = 24.
if (isco08aneu = 23 and dw03 = 3) eseg = 25.
if (isco08aneu = 30) and (STAa = 2)  and (dw03 = 3) eseg = 30. 
if (any(isco08aneu, 31, 35) and STAa = 2 and dw03 = 3) eseg = 31.
if (isco08aneu = 32 and STAa = 2 and dw03 = 3) eseg = 32.
if (isco08aneu = 33 and STAa = 2 and dw03 = 3) eseg = 33.
if (isco08aneu = 34 and STAa = 2 and dw03 = 3) eseg = 34.
if (isco08aneu = 02 and STAa = 2 and dw03 = 3) eseg = 35.
if ((isco08aneu >= 30 and isco08aneu <= 96) and STAa = 1 and dw03 = 3) eseg = 40. 
if (any(isco08aneu, 60, 61, 62, 63, 92) and STAa = 1 and dw03 = 3) eseg = 41.
if (isco08aneu >= 31 and isco08aneu <= 54 and STAa = 1 and dw03 = 3) eseg = 42.
if (isco08aneu >= 71 and isco08aneu <= 96 and isco08aneu ne 92 and STAa = 1 and dw03 = 3) eseg = 43.
if (isco08aneu = 40) and (STAa = 2) and (dw03 = 3) eseg = 50. 
if (any(isco08aneu, 41,  43, 44) and STAa = 2 and dw03 = 3) eseg = 51.
if (isco08aneu = 42 and STAa = 2 and dw03 = 3) eseg = 52.
if (isco08aneu = 53 and STAa = 2 and dw03 = 3) eseg = 53.
if (any(isco08aneu, 03, 04, 54) and STAa = 2 and dw03 = 3) eseg = 54.
if (any(isco08aneu, 70, 80) and STAa = 2 and dw03 = 3) eseg = 60. 
if (isco08aneu = 71 and STAa = 2 and dw03 = 3) eseg = 61.
if (isco08aneu = 75 and STAa = 2 and dw03 = 3) eseg = 62.
if (any(isco08aneu, 72, 73, 74) and STAa = 2 and dw03 = 3) eseg = 63.
if (any(isco08aneu, 81, 82) and STAa = 2 and dw03 = 3) eseg = 64.
if (isco08aneu = 83 and STAa = 2 and dw03 = 3) eseg = 65.
if any(isco08aneu, 60, 90) and (STAa = 2) and (dw03 = 3) eseg = 70. 
if (any(isco08aneu, 51, 52) and STAa = 2 and dw03 = 3) eseg = 71.
if (any(isco08aneu, 93, 94, 96) and STAa = 2 and dw03 = 3) eseg = 72.
if (any(isco08aneu, 91, 95) and STAa = 2 and dw03 = 3) eseg = 73.
if (any(isco08aneu, 60, 61, 62, 63, 92) and STAa = 2 and dw03 = 3) eseg = 74.


****Gruppen 8 und 9*****.

*****Befragter: Klassifizierung der Rentner.
*** 8 Retired persons.
*8.0 Retired persons - not further specified.
if (dw03 = 2) eseg = 80. 
*8.1 Retired Managers.
if (any(isco08aneu, 01, 10, 11, 12, 13, 14) and dw03 = 2) eseg = 81.
*8.2 Retired professionals.
if (any(isco08aneu, 20, 21, 22, 23, 24, 25, 26) and dw03 = 2) eseg = 82.
*8.3 Retired technicians and associate professionals.
if (any(isco08aneu, 02, 30, 31, 32, 33, 34, 35) and (STAa = 2) and (dw03 = 2)) eseg = 83.
*8.4 Retired small entrepreneurs.
if ((isco08aneu ge 30) and (isco08aneu le 96) and (STAa = 1) and (dw03 = 2)) eseg = 84.
*8.5 Retired skilled service workers.
if (any(isco08aneu, 03, 40, 41, 42, 43, 44, 53, 54) and (STAa = 2) and dw03 = 2) eseg = 85.
*8.6 Retired skilled blue-collars.
if ((isco08aneu ge 70) and (isco08aneu le 83) and (STAa = 2) and dw03 = 2)eseg = 86.
*8.7 Retired less skilled workers.
if (any(isco08aneu, 51, 52, 60, 61, 62, 63, 90, 91, 92, 93, 94, 95, 96) and (STAa = 2) and (dw03 = 2)) eseg = 87.

*****Ehepartner und Lebenspartner - Klassifizierung der Rentner.
do repeat #ESEG = sceseg peseg
        / #DW03 = scdw03 pdw03.
*** 8 Retired persons.
*8.0 Retired persons - not further specified.
if (#DW03 = 2) #ESEG = 80. 
end repeat.

*****Befragter, Ehepartner und Lebenspartner - Klassifizierung der nicht erwerbstätigen Personen.
do repeat #ESEG = eseg sceseg peseg
        / #DW03 = dw03 scdw03 pdw03.
*** 9 Other persons outside the Labour Force.
if any(#DW03, 1, 4, 5, 6) and (#ESEG = 0) #ESEG = 90.
*9.1 Student.
if (#DW03 = 1) #ESEG = 91.
*9.2 Permanently disabled: Kann nicht gebildet werden.
*9.9 Other inactive aged less than 65 years.
if (any(#DW03, 4, 5, 6)) #ESEG = 99.
end repeat.

****Vater und Mutter: Klassifizierung der nicht erwerbstätigen Personen.
*Vater:.
if (fdw01 eq -50) feseg = 80.
if (fdw01 eq -53) feseg = 90.
*Mutter:.
** ESEG 8-9: Nicht erwerbstaetig -> Sondercode 900.
if (mdw01 = -53) or (misco08 = -50) meseg = 900.

**** Gruppe 0: Persons in the labour force, whose occupation or status in employment is not known ****.
do repeat #WORK = work scwork pwork
	/ #ESEG = eseg sceseg peseg
	/ #DW = dw03 scdw03 pdw03.
+ if any(#WORK, 1, 2) and (#ESEG eq 0) #ESEG = 01.
+ if (#DW eq 3) and (#ESEG eq 0) #ESEG = 02.
end repeat.

if ((fisco08 eq -33 or fdw01 gt 0) & feseg eq 0) feseg = 01.
if (fdw01 eq -51) feseg = 02.

if (mdw01 gt 0 & meseg eq 0) meseg = 01.


****Missing Values.
*Befragter:.
if eseg = 0 and any(-9, dw01, work, dw03) eseg = -32.
*Ehepartner:.
if not any(mstat, 1, 6) sceseg = -10.
if sceseg = 0 and any(-9, scdw01, scdw03, scwork) sceseg = -32.
*Lebenspartner:.
if (value(dp01) ne 1) peseg = -10.
if peseg = 0 and any(-9, pdw01, pdw03, pwork) peseg = -32.
*Vater:.
if feseg = 0 and any(fdw01, -9, -8, -54, -55, -52) feseg = -32.
*Mutter:.
if meseg = 0 and any(mdw01, -9, -8, -54) meseg = -32.
execute.

*Label.
variable labels eseg "BEFR.: SOZIO-OEKONOMISCHE GRUPPE (ESEG)". 
variable labels sceseg "GEGENW.EHEP.: SOZIO-OEKON.GRUPPE (ESEG)". 
variable labels peseg "LEBENSPARTNER: SOZIO-OEKON.GRUPPE (ESEG)". 
variable labels feseg "VATER: SOZIO-OEKONOMISCHE GRUPPE (ESEG)".
variable labels meseg "MUTTER: SOZIO-OEKONOMISCHE GRUPPE (ESEG)". 


**************************************.

*Value Labels.

value labels eseg sceseg peseg feseg meseg 
01 "EMPLOYED, NO GROUP"
02 "UNEMPLOYED, NO GROUP"
10 "MANAGERS"  
11 "HIGHER MG. SELF-EMP."
12 "LOWER MG. SELF-EMP."  
13 "HIGHER MG. EMPLOYEES" 
14 "LOWER MG. EMPLOYEES"  
20 "PROFESSIONALS"
21 "SCIENCE/ICT PROF."
22 "HEALTH PROFESSIONALS"  
23 "BUSINESS PROF."  
24 "LEGAL/SOCIAL PROF."  
25 "TEACHING PROF."  
30 "PROFESSIONAL EMP."
31 "TECHNICIANS"
32 "HEALTH ASS. PROF."  
33 "BUSINESS ASS. PROF." 
34 "LEGAL/SOCIAL ASS.PRO"  
35 "NCOS"
40 "SMALL ENTREPRENEURS"  
41 "AGRIC. SELF-EMPLOYED"  
42 "SELF-EMPLOYED TECHN."  
43 "CRAFT ETC. SELF-EMP."  
50 "CLERKS/SERVICE EMP."
51 "GENERAL CLERKS"  
52 "CUSTOMER SERVICE CL."  
53 "PERSONAL CARE EMP."  
54 "PROTECTIVE SERVICS"  
60 "INDUSTRIAL EMPLOYEES"
61 "BUILDING EMPLOYEES"  
62 "FOOD PROCESSING ETC."  
63 "METAL/MACHINERY ETC."  
64 "STATIONARY PLANT OP."  
65 "MOBILE PLANT OP." 
70 "LOWER STATUS EMP."  
71 "SERVICE/SALES EMP." 
72 "BLUE COLLAR EMP."  
73 "CLEANERS AND HELPERS"  
74 "AGRICULTURAL EMP."  
80 "RETIRED PERSONS"
81 "RETIRED MANAGERS"
82 "RETIRED PROF."
83 "RETIRED TECHNICIANS"
84 "R. ENTREPRENEURS"
85 "RETIRED CLERKS"
86 "R. INDUSTRIAL EMP."
87 "R. LOWER STATUS EMP."
90 "OTHERS OUTSIDE LF"
91 "STUDENTS" 
99 "OTHER INACTIVE"
-34 "NICHT ENTHALTEN"
-32 "NICHT GENERIERBAR"
-10 "TNZ: FILTER".

add value labels meseg
900 "NON-EMPLOYED PERSONS".

**************************************.
****Kumulation: ESeG vor 2012 nicht generierbar.

do repeat #ESEG = eseg sceseg peseg feseg meseg.
if (year < 2012) #ESEG = -34.
end repeat.
execute.

**************************************.

*Aufraeumen.

formats eseg sceseg peseg feseg meseg (F3).
missing values eseg sceseg peseg feseg meseg (LO thru -1).
missing values isco08 dw01 dw03 work isco08a dw01a mstat scisco08 scdw01 scdw03 scwork pisco08 pdw01 pdw03 pwork fdw01 fisco08 mdw01 misco08 (LO thru -1).
delete variables isco08neu isco08aneu scisco08neu pisco08neu fisco08neu misco08neu STA STAa scSTA pSTA fSTA mSTA.

*Haeufigkeitstabellen.
frequencies eseg sceseg peseg feseg meseg.

*Speichern.
SAVE OUTFILE='ZA4586_eseg.sav'
  /COMPRESSED.